@mixin portrait($animate: true, $scale: 1.05) {
  &:hover > img {
    transform: scale($scale);
  }

  > img {
    border-radius: 50%;
    vertical-align: middle;
    padding: $padding-vertical;
    border: 4px solid $color-gray-light;
    @if $animate == true {
      transition: transform .25s ease-out, box-shadow .25s ease-out;
    }

  }
}

@mixin portrait-still() {
  @include portrait($animate: false, $scale: 1);
}
